@@ -38,7 +38,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "1.0.9"
+#define LIBGNUTLS_VERSION "1.0.11"
 
 #ifndef HAVE_SIZE_T
 # define HAVE_SIZE_T
@@ -164,11 +164,15 @@ typedef enum gnutls_pk_algorithm { GNUTLS_PK_RSA = 1, GNUTLS_PK_DSA,
 	GNUTLS_PK_UNKNOWN = 0xff
 } gnutls_pk_algorithm;
 
+const char *gnutls_pk_algorithm_get_name( gnutls_pk_algorithm algorithm);
+
 typedef enum gnutls_sign_algorithm { GNUTLS_SIGN_RSA_SHA = 1, GNUTLS_SIGN_DSA_SHA,
 	GNUTLS_SIGN_RSA_MD5, GNUTLS_SIGN_RSA_MD2,
 	GNUTLS_SIGN_UNKNOWN = 0xff
 } gnutls_sign_algorithm;
 
+const char *gnutls_sign_algorithm_get_name( gnutls_sign_algorithm algorithm);
+
 /* If you want to change this, then also change the 
  * define in gnutls_int.h, and recompile.
  */
