@@ -5,7 +5,6 @@
 #ifndef GNUTLS_OPENPGP_H
 #define GNUTLS_OPENPGP_H
 
-#include <gnutls/compat8.h>
 #include <auth_cert.h>
 #include <opencdk.h>
 
@@ -68,10 +67,14 @@ int gnutls_openpgp_recv_key(
     gnutls_datum *key );
 
 /* internal */
-int _gnutls_openpgp_cert2gnutls_cert(
+int _gnutls_openpgp_raw_key_to_gcert(
     gnutls_cert *cert,
     const gnutls_datum *raw );
 
+int
+_gnutls_openpgp_raw_privkey_to_gkey( gnutls_privkey *pkey,
+                                const gnutls_datum *raw_key);
+
 int
 _gnutls_openpgp_request_key(
     gnutls_session,
@@ -84,15 +87,14 @@ keybox_blob* kbx_read_blob( const gnutls_datum* keyring, size_t pos );
 cdk_keydb_hd_t kbx_to_keydb( keybox_blob *blob );
 void kbx_blob_release( keybox_blob *ctx );
 
-int gnutls_openpgp_verify_key(const char *trustdb,
+int _gnutls_openpgp_verify_key(const char *trustdb,
 			  const gnutls_datum * keyring,
 			  const gnutls_datum * cert_list,
 			  int cert_list_length);
-int gnutls_openpgp_fingerprint(const gnutls_datum * cert,
+int _gnutls_openpgp_fingerprint(const gnutls_datum * cert,
 			   unsigned char *fpr, size_t * fprlen);
-time_t gnutls_openpgp_extract_key_creation_time(const gnutls_datum * cert);
-time_t gnutls_openpgp_extract_key_expiration_time(const gnutls_datum * cert);
-
+time_t _gnutls_openpgp_get_raw_key_creation_time(const gnutls_datum * cert);
+time_t _gnutls_openpgp_get_raw_key_expiration_time(const gnutls_datum * cert);
 
 #endif /*GNUTLS_OPENPGP_H*/
 
